@@ -20,7 +20,7 @@
  * @author Akinobu Lee
  * @date   Thu May 12 13:31:47 2005
  *
- * $Revision: 1.13 $
+ * $Revision: 1.14 $
  * 
  */
 /*
@@ -1115,6 +1115,9 @@ j_launch_recognition_instance(Recog *recog, JCONF_SEARCH *sconf)
   p->backtrellis = (BACKTRELLIS *)mymalloc(sizeof(BACKTRELLIS));
   bt_init(p->backtrellis);
 
+  /* prepare work area for 2nd pass */
+  wchmm_fbs_prepare(p);
+
   jlog("STAT: SR%02d %s composed\n", sconf->id, sconf->name);
 
   if (sconf->sw.start_inactive) {
