@@ -5,8 +5,7 @@
  * @brief Definitions for word N-gram
  *
  * This file defines a structure for word N-gram language model.
- * Julius now support N-gram for arbitrary N (maximum number of N is defined
- * as MAX_N, and N should be >= 2).
+ * Julius now support N-gram for arbitrary N.
  *
  * Both direction of forward (left-to-right) N-gram and backward
  * (right-to-left) N-gram is supported.  Since the final recognition
@@ -57,7 +56,6 @@
  *
  * ΥեˤñN-gramǥǼ뤿ι¤
  * ޤޤƤޤJulius N-gramˤǤդ N 򥵥ݡȤޤ
- * N ξͤ MAX_N Ƥޤ
  *
  * ̾ (left-to-right) ȸ (right-to-left)  N-gram 
  * ݡȤƤޤǧκǽѥ2ѥˤϸ˹ԤΤǡ
@@ -97,7 +95,7 @@
  * @author Akinobu LEE
  * @date   Fri Feb 11 15:04:02 2005
  *
- * $Revision: 1.6 $
+ * $Revision: 1.8 $
  * 
  */
 /*
@@ -113,8 +111,6 @@
 #include <sent/stddefs.h>
 #include <sent/ptree.h>
 
-#define MAX_N 10		///< Maximum number of N for N-gram
-
 typedef unsigned int NNID;	      ///< Type definition for N-gram entry ID (full)
 #define NNID_INVALID 0xffffffff  ///< Value to indicate no id (full)
 #define NNID_MAX 0xfffffffe	///< Value of maximum value (full)
@@ -180,7 +176,7 @@ typedef struct __ngram_info__ {
   LOGPROB unk_num_log;		///< Log10 value of @a unk_num, used for calculating probability of unknown words
   boolean isopen;		///< TRUE if dictionary has unknown words, which does not appear in this N-gram
 
-  NGRAM_TUPLE_INFO d[MAX_N];	///< Main body of N-gram info
+  NGRAM_TUPLE_INFO *d;	///< Main body of N-gram info
 
   /* for pass1 */
   LOGPROB *bo_wt_1;		///< back-off weights for 2-gram on 1st pass
@@ -219,6 +215,11 @@ typedef struct __ngram_info__ {
 #define BINGRAM_NATURAL_BYTEORDER "LE"
 #endif
 
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* function declaration */
 NNID search_ngram(NGRAM_INFO *ndata, int n, WORD_ID *w);
 LOGPROB ngram_prob(NGRAM_INFO *ndata, int n, WORD_ID *w);
@@ -249,4 +250,8 @@ void print_ngram_info(FILE *fp, NGRAM_INFO *ndata);
 boolean make_voca_ref(NGRAM_INFO *ndata, WORD_INFO *winfo);
 void fix_uniprob_srilm(NGRAM_INFO *ndata, WORD_INFO *winfo);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __SENT_NGRAM2_H__ */
