@@ -20,7 +20,7 @@
  * @author Akinobu LEE
  * @date   Thu Feb 17 18:12:30 2005
  *
- * $Revision: 1.3 $
+ * $Revision: 1.5 $
  * 
  */
 /*
@@ -253,7 +253,7 @@ CMN_realtime_new(Value *para, float weight)
   c = (CMNWork *)mymalloc(sizeof(CMNWork));
 
   c->cweight = weight;
-  c->mfcc_dim = para->mfcc_dim + (para->c0 ? 1 : 0);
+  c->mfcc_dim = para->mfcc_dim; // + (para->c0 ? 1 : 0);
   c->veclen = para->veclen;
   c->mean = para->cmn ? TRUE : FALSE;
   c->var = para->cvn ? TRUE : FALSE;
@@ -582,7 +582,11 @@ CMN_save_to_file(CMNWork *c, char *filename)
 
   jlog("Stat: wav2mfcc-pipe: writing current cepstral data to file \"%s\"\n", filename);
 
-  if ((fd = creat(filename, 0644)) == -1) {
+  if ((fd = open(filename, O_CREAT | O_RDWR
+#ifdef O_BINARY
+		 | O_BINARY
+#endif
+		 , 0644)) == -1) {
     jlog("Error: wav2mfcc-pipe: failed to open \"%s\" to write current cepstral data\n", filename);
     return(FALSE);
   }
